@@ -1449,7 +1449,7 @@
 					e.preventDefault();
 					return;
 				case KEY_RETURN:
-					if (!e.shiftKey && self.$activeOption) {
+					if (self.isOpen && self.$activeOption) {
 						self.onOptionSelect({currentTarget: self.$activeOption});
 					}
 					e.preventDefault();
@@ -2512,12 +2512,6 @@
 			self.$dropdown.css({visibility: 'visible'});
 			self.trigger('dropdown_open', self.$dropdown);
 		},
-
-                show: function() {
-                        this.$dropdown.css({visibility: 'hidden', display: 'block'});
-                        this.positionDropdown();
-                        this.$dropdown.css({visibility: 'visible'});
-                },
 	
 		/**
 		 * Closes the autocomplete dropdown menu.
@@ -3335,4 +3329,4 @@
 	});
 
 	return Selectize;
-}));
+}));
\ No newline at end of file
